@@ -1,4 +1,5 @@
-import mysql.connector
+# import mysql.connector
+import pymysql
 import numpy as np
 import pandas as pd
 import math
@@ -12,35 +13,33 @@ class Resensys():
     def __init__(self,username,password):
         self.username = username
         self.password = password
-        self.host = 'resensys.net'
+        self.encoded_password = self.password_encoding_generator(password)
+        # self.host = 'resensys.net'
         self.connect()
     
     def connect(self):
         # define ssh connection
 
-        # decrypt user password
-        self.password_encoding_generator()
-        config = {  
-            'user': self.username,
-            'password': self.encoded_password,
-            'host': self.host,
-            'port': 3306,
-            # 'tls_versions':['TLSv1.1']
-            'ssl_disabled': True,
+        # config = {  
+        #     'user': self.username,
+        #     'password': self.encoded_password,
+        #     'host': "resensys.net",
+        #     'port': 3306,
+        # }
 
-            # Create SSL connection with the self-signed certificate
-            # 'ssl_verify_cert': False,
-        }
+
+        # Create SSL connection with the self-signed certificate
+        # 'ssl_verify_cert': False,
 
         # self.conn = mysql.connector.connect(user=self.username,password=self.encoded_password,host=self.host)
-        self.conn = mysql.connector.connect(**config,use_pure=True)
+        self.conn = pymysql.connect(user=self.username,password=self.encoded_password,host="resensys.net",port=3306)
         return self.conn
     
     def getCredentials(self):
         return self.username,self.password
     
-    def password_encoding_generator(self):
-        password_bytes = bytes(self.password, 'ascii')
+    def password_encoding_generator(self,p):
+        password_bytes = bytes(p, 'ascii')
         byte_list = []
         for byte in password_bytes:
             byte_list.append(byte)
@@ -53,7 +52,7 @@ class Resensys():
         encoded_characters = []
         for j in range(len(reverse_list)):
             encoded_characters.append(chr(reverse_list[j]))
-        self.encoded_password = ''.join(encoded_characters)
+        return ''.join(encoded_characters)
 
     def add_new_site(self,SID):
         self.serverTool.add_site_to_user(self, self.username, SID, acc_pswd="", mode=0, extra_criterion="")
